.. _Database_Schema:

Database schema
===============

Database schema is designed with a `MySQL Workbench  <http://dev.mysql.com/downloads/workbench/>`_.
It is :download:`available here <_static/mysmile_database_schema.mwb>`.

.. image:: _static/images/database_schema.png
